@@ -1,13 +1,12 @@
-mod groupable;
+// mod groupable;
 mod selectable;
 
 // -----------------------------------------------------------------------------
 
-pub use crate::select2::groupable::Groupable;
-pub use crate::select2::groupable::GroupRecord;
-pub use crate::select2::groupable::results as groupable_results;
-pub use crate::select2::selectable::results as selectable_results;
-pub use crate::select2::selectable::Selectable;
+// pub use crate::select2::groupable::Groupable;
+// pub use crate::select2::groupable::GroupRecord;
+// pub use crate::select2::groupable::results as groupable_results;
+pub use crate::select2::selectable::{Results as SelectableResults, Selectable, SelectableIndex, SelectableRecord};
 
 // -----------------------------------------------------------------------------
 
