@@ -95,13 +95,24 @@ where
     /// assert_eq!(search_results, vec![&1, &0]);
     /// ```
 
+    #[tracing::instrument(level = "trace", name = "Search", skip(self))]
     pub fn search(&'a self, string: &'a str) -> Vec<&'a K> {
 
-        match &self.search_type {
+        let search_results: Vec<&'a K> = match self.search_type {
             SearchType::And => self.search_and(string),
             SearchType::Keyword => self.search_keyword(string).iter().cloned().collect(),
             SearchType::Or => self.search_or(string),
-        } // match
+        }; // match
+
+        // For debug builds:
+        #[cfg(debug_assertions)]
+        tracing::trace!(
+            "{} search results for \"{}\".",
+            search_results.len(),
+            string,
+        ); // trace!
+
+        search_results
 
     } // fn
 
@@ -116,8 +127,9 @@ where
     /// an ergonomic alternative to fuzzy matching.
     ///
     /// Search behaviour can be changed by using different `SearchType` variants
-    /// as the first parameter for the method call. See [`SearchType`] for more
-    /// information on the different search types.
+    /// as the first parameter for the method call, effectively overriding the
+    /// index settings. See [`SearchType`] for more information on the different
+    /// search types.
     ///
     /// [`SearchType`]: enum.SearchType.html
     ///
@@ -183,13 +195,24 @@ where
     /// assert_eq!(search_results, vec![&3]);
     /// ```
 
+    #[tracing::instrument(level = "trace", name = "Search", skip(self))]
     pub fn search_type(&'a self, search_type: &SearchType, string: &'a str) -> Vec<&'a K> {
 
-        match search_type {
+        let search_results: Vec<&'a K> = match search_type {
             SearchType::And => self.search_and(string),
             SearchType::Keyword => self.search_keyword(string).iter().cloned().collect(),
             SearchType::Or => self.search_or(string),
-        } // match
+        }; // match
+
+        // For debug builds:
+        #[cfg(debug_assertions)]
+        tracing::trace!(
+            "{} search results for \"{}\".",
+            search_results.len(),
+            string,
+        ); // trace!
+
+        search_results
 
     } // fn
 
